import Vue from 'vue'
import Router from 'vue-router'
import Layout from '@/views/layout/Layout'
import FullScreen from '@/views/layout/FullScreen'
import { cookie, getSession } from '@/utils/storage'
const _import = require('./_import_' + process.env.NODE_ENV)
Vue.use(Router)

export const constantRouterMap = [
  {
    path: '/404',
    hidden: true,
    component: _import('errorPage/404')
  },
  {
    path: '/401',
    hidden: true,
    component: _import('errorPage/401')
  },
  {
    path: '',
    redirect: 'home',
    component: Layout,
    children: [{
      path: 'home',
      name: 'home',
      component: _import('home/index'),
      meta: { title: '首页', icon: 'home' }
    }]
  }
]

export const authRouterMap = [
  // ,
  // {
  //   path: '/develop',
  //   redirect: '/develop/defineAPI',
  //   alwaysShow: true,
  //   component: Layout,
  //   meta: { title: 'develop', icon: 'code' },
  //   children: [
  //     {
  //       name: 'defineAPI',
  //       path: 'defineAPI',
  //       component: _import('develop/defineAPI/index'),
  //       meta: { title: '定义API', icon: 'form' }
  //     }
  //   ]
  // }
]

export const otherRouterMap = [
  // {
  //   path: '/local',
  //   redirect: '/local/test',
  //   alwaysShow: true,
  //   // component: Layout,
  //   component: FullScreen,
  //   // hidden: process.env.NODE_ENV !== 'development',
  //   meta: { title: 'local', icon: 'code' },
  //   children: [
  //     {
  //       name: 'OrderAnalysis',
  //       path: 'OrderAnalysis',
  //       component: _import('chart/OrderAnalysis'),
  //       meta: { title: 'OrderAnalysis', icon: 'bug' }
  //     }
  //     // {
  //     //   name: 'test',
  //     //   path: 'test',
  //     //   component: _import('develop/test/test'),
  //     //   meta: { title: 'test', icon: 'bug' },
  //     //   props: { test: 'world' }
  //     // }
  //     // {
  //     //   name: 'inline',
  //     //   path: 'inline',
  //     //   component: _import('develop/test/inline'),
  //     //   meta: { title: 'inline', icon: 'guide' }
  //     // }
  //     // {
  //     //   name: 'icon',
  //     //   path: 'icon',
  //     //   component: () => import('@/views/develop/icons'),
  //     //   meta: { title: 'icon', icon: 'icon', noCache: true }
  //     // }
  //   ]
  // },
  { path: '*', redirect: '/404', hidden: true }
]

const reportTable = _import('report/reportTable')
const reportChart = _import('report/reportChart')

const authRouterReport = {
  path: '/report',
  alwaysShow: true,
  component: Layout,
  meta: { title: '报表', icon: 'table' },
  children: [
    {
      name: 'svop',
      path: 'svop',
      component: _import('report/svop'),
      meta: { title: 'svop' }
    },
    {
      name: 'capitalFlow',
      path: 'capitalFlow',
      component: _import('report/capitalFlow'),
      meta: { title: '资金流水' }
    }
  ]
}
const authRouterCharts = {
  path: '/charts',
  alwaysShow: true,
  component: FullScreen,
  meta: { title: '图表', icon: 'chart' },
  children: [
    {
      name: 'complex',
      path: 'complex',
      component: _import('charts/complex'),
      meta: { title: '综合图表' }
    },
    {
      name: 'chartContainer',
      path: '/chartContainer',
      alwaysShow: true,
      component: _import('chart/chartContainer'),
      meta: { title: '单表' },
      children: [
        {
          name: 'CurrentOrderQuantity',
          path: 'CurrentOrderQuantity',
          component: _import('chart/CurrentOrderQuantity'),
          meta: { title: '今日订单量详情' }
        },
        {
          name: 'CurrentOrderDetails',
          path: 'CurrentOrderDetails',
          component: _import('chart/CurrentOrderDetails'),
          meta: { title: '当前订单详情' },
          props: { height: '60%' }
        },
        {
          name: 'CurrentOperatorDetails',
          path: 'CurrentOperatorDetails',
          component: _import('chart/CurrentOperatorDetails'),
          meta: { title: '当前客服详情' }
        },
        {
          name: 'CurrentPolicyUserDetails',
          path: 'CurrentPolicyUserDetails',
          component: _import('chart/CurrentPolicyUserDetails'),
          meta: { title: '当前政策详情' }
        },
        {
          name: 'CreditCardUsageStatusCharts',
          path: 'CreditCardUsageStatusCharts',
          component: _import('chart/CreditCardUsageStatusCharts'),
          meta: { title: '信用卡使用情况' }
        },
        {
          name: 'CurrentOrderDynamics',
          path: 'CurrentOrderDynamics',
          component: _import('chart/CurrentOrderDynamics'),
          meta: { title: '当前订单动态' }
        },
        {
          name: 'OperatorTicketIssueSpeed',
          path: 'OperatorTicketIssueSpeed',
          component: _import('chart/OperatorTicketIssueSpeed'),
          meta: { title: '客服出票量' }
        },
        {
          name: 'VerifyStatistical',
          path: 'VerifyStatistical',
          component: _import('chart/VerifyStatistical'),
          meta: { title: '验价统计' }
        },
        {
          name: 'OccupyingSeatStatistical',
          path: 'OccupyingSeatStatistical',
          component: _import('chart/OccupyingSeatStatistical'),
          meta: { title: '占舱统计' }
        },
        {
          name: 'OrderAnalysis',
          path: 'OrderAnalysis',
          component: _import('chart/OrderAnalysis'),
          meta: { title: '订单每日同比' }
        }
      ]
    }
  ]
}
export function createdMenu(menu) {
  const routers = []
  menu.forEach(e => {
    if (e.children || e.children.length) {
      let temp
      if (e.url === 'reportForms') {
        temp = {
          path: '/report',
          component: Layout,
          alwaysShow: true,
          meta: { title: e.title || '报表', icon: e.icon || 'table' },
          children: e.children.map(e0 => {
            return {
              path: e0.url,
              name: e0.url,
              component: reportTable,
              meta: { title: e0.title, moduleCode: e0.url, name: 'reportTable' },
              props: { moduleCode: e0.url }
            }
          })
        }
      } else if (e.url === 'reportChart') {
        temp = {
          path: '/report',
          component: FullScreen,
          alwaysShow: true,
          meta: { title: e.title || '图表', icon: e.icon || 'chart' },
          children: e.children.map(e0 => {
            return {
              path: e0.url,
              name: e0.url,
              component: reportChart,
              meta: { title: e0.title, moduleCode: e0.url, name: 'reportChart' },
              props: { moduleCode: e0.url }
            }
          })
        }
      } else if (e.url === 'authRouterReport') {
        temp = authRouterReport
      } else if (e.url === 'authRouterCharts') {
        temp = authRouterCharts
      } else if (e.url) {
        temp = {
          path: '/' + e.url,
          alwaysShow: true,
          component: Layout,
          meta: { title: e.title, icon: e.icon },
          children: e.children.map(e0 => {
            return {
              name: e0.url,
              path: e0.url,
              component: _import(e.url + '/' + e0.url + '/index'),
              meta: { title: e0.title, icon: e0.icon }
            }
          })
        }
      }
      temp && routers.push(temp)
    }
  })
  return routers
}

export let routes = constantRouterMap.concat(otherRouterMap)

if (process.env.NODE_ENV === 'production' || process.env.BASE_URL === 'http://localhost:10011/') {
  if (cookie.get_user()) {
    if (getSession('menu')) {
      routes = constantRouterMap.concat(createdMenu(getSession('menu')), authRouterMap, otherRouterMap)
    } else {
      routes = constantRouterMap.concat(authRouterMap, otherRouterMap)
    }
  }
} else if (process.env.NODE_ENV === 'development' && process.env.BASE_URL === 'http://ota.tripto.cn/') {
  routes = constantRouterMap.concat(authRouterMap, otherRouterMap)
}

export const menuRouters = routes

const router = new Router({
  // mode: 'history', // 后端支持可开
  scrollBehavior: () => ({ y: 0 }),
  routes: routes
})

export default router
