import { auth, logout } from '@/api/auth'
import openWindow from '@/utils/openWindow'
import { cookie, clearCookies, clearAll } from '@/utils/storage'
import defaultAvatar from '@/assets/default_avatar.gif'
const user = {
  state: {
    user: cookie.get_user(),
    avatar: defaultAvatar
  },
  mutations: {
    SET_USER: (state, user) => {
      state.user = user
      state.avatar = user && user.avatar ? user.avatar : defaultAvatar
      cookie.set_user(user)
    }
  },
  actions: {
    SetUser({ commit }, user) {
      commit('SET_USER', user)
    },
    DetectLoginStatus({ commit }) {
      return new Promise((resolve, reject) => {
        auth().then(({ data }) => {
          if (data.ret) {
            commit('SET_USER', data)
            resolve(data)
          } else {
            clearAll()
            commit('SET_USER', null)
            reject(data)
          }
        }).catch(err => {
          reject(err)
        })
      })
    },
    Login() {
      openWindow(window.location.origin + 'a/login', {
        title: '登录',
        w: 540,
        h: 540,
        done(newWindow) {
          var href = newWindow.location.href
          const timer = setInterval(() => {
            if (newWindow.location.href !== href) {
              clearInterval(timer)
              newWindow.close()
            }
          }, 1000)
        },
        fail() { location.href = process.env.BASE_URL + 'a/login' },
        close() { location.reload() }
      })
    },
    Logout() {
      return new Promise((resolve, reject) => {
        logout().finally(e => {
          clearCookies()
          clearAll()
          resolve(e)
        })
      })
    }
  }
}

export default user
