import Cookie from 'js-cookie'
import { __AESencrypt, __AESdecrypt } from '@/utils/crypto'

const cookie = {}
const cookieKeys = [
  { key: 'user', encryptKey: __AESencrypt('user') },
  { key: 'menu', encryptKey: __AESencrypt('menu') },
  { key: 'sidebarStatus', encryptKey: __AESencrypt('sidebarStatus') }
]
cookieKeys.forEach(e => {
  cookie['set_' + e.key] = (plaintext, config) => Cookie.set(e.encryptKey, __AESencrypt(plaintext instanceof Object ? JSON.stringify(plaintext) : plaintext), Object.assign({ expires: 0.5 }, config))
  cookie['get_' + e.key] = () => {
    const ciphetext = Cookie.get(e.encryptKey)
    const plaintext = ciphetext && __AESdecrypt(ciphetext)
    return plaintext && JSON.parse(plaintext)
  }
  cookie['remove_' + e.key] = () => Cookie.remove(e.encryptKey)
})

function clearCookies() { cookieKeys.forEach(e => Cookie.remove(e.encryptKey)) }

export { cookie, clearCookies }

export function setSession(key, plaintext) {
  if (key) {
    return sessionStorage.setItem(__AESencrypt(key), __AESencrypt(plaintext instanceof Object ? JSON.stringify(plaintext) : plaintext))
  }
}
export function getSession(key) {
  if (key) {
    const ciphetext = sessionStorage.getItem(__AESencrypt(key))
    const plaintext = ciphetext && __AESdecrypt(ciphetext)
    return plaintext && JSON.parse(plaintext)
  }
}
export function removeSession(key) {
  return sessionStorage.removeItem(__AESencrypt(key))
}
export function clearSession() {
  return sessionStorage.clear()
}

export function setLocal(key, plaintext) {
  if (key) {
    return localStorage.setItem(__AESencrypt(key), __AESencrypt(plaintext instanceof Object ? JSON.stringify(plaintext) : plaintext))
  }
}
export function getLocal(key) {
  if (key) {
    const ciphetext = localStorage.getItem(__AESencrypt(key))
    const plaintext = ciphetext && __AESdecrypt(ciphetext)
    return plaintext && JSON.parse(plaintext)
  }
}
export function removeLocal(key) {
  return localStorage.removeItem(__AESencrypt(key))
}
export function clearLocal() {
  return localStorage.clear()
}
export function clearAll() {
  cookieKeys.forEach(e => Cookie.remove(e.encryptKey))
  localStorage.clear()
  sessionStorage.clear()
}

